@@ -49,6 +49,7 @@ from alchemite_apiclient.model.drumap_reduction_type import DRUMAPReductionType
 from alchemite_apiclient.model.data import Data
 from alchemite_apiclient.model.dataset import Dataset
 from alchemite_apiclient.model.dataset1 import Dataset1
+from alchemite_apiclient.model.dataset_calculated_columns import DatasetCalculatedColumns
 from alchemite_apiclient.model.dataset_chunk import DatasetChunk
 from alchemite_apiclient.model.dataset_or_data import DatasetOrData
 from alchemite_apiclient.model.dataset_patch import DatasetPatch
@@ -110,16 +111,25 @@ from alchemite_apiclient.model.historic_vector_prediction import HistoricVectorP
 from alchemite_apiclient.model.historic_vector_value import HistoricVectorValue
 from alchemite_apiclient.model.importance_request import ImportanceRequest
 from alchemite_apiclient.model.impute_request import ImputeRequest
+from alchemite_apiclient.model.inline_response200 import InlineResponse200
+from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
 from alchemite_apiclient.model.job_patch import JobPatch
 from alchemite_apiclient.model.load_request import LoadRequest
+from alchemite_apiclient.model.max import Max
+from alchemite_apiclient.model.min import Min
 from alchemite_apiclient.model.model import Model
 from alchemite_apiclient.model.model_column_info import ModelColumnInfo
 from alchemite_apiclient.model.model_patch import ModelPatch
 from alchemite_apiclient.model.model_permitted_column_relationships import ModelPermittedColumnRelationships
+from alchemite_apiclient.model.model_query import ModelQuery
+from alchemite_apiclient.model.model_status import ModelStatus
+from alchemite_apiclient.model.model_validation_methods import ModelValidationMethods
 from alchemite_apiclient.model.models_dataset_put_request import ModelsDatasetPutRequest
 from alchemite_apiclient.model.models_id_additive_sensitivity_origin import ModelsIdAdditiveSensitivityOrigin
 from alchemite_apiclient.model.models_id_train_permitted_column_relationships import ModelsIdTrainPermittedColumnRelationships
+from alchemite_apiclient.model.models_metadata_filters import ModelsMetadataFilters
+from alchemite_apiclient.model.models_metadata_sort import ModelsMetadataSort
 from alchemite_apiclient.model.new_col_fn_arg_col import NewColFnArgCol
 from alchemite_apiclient.model.new_col_fn_arg_col_all_of import NewColFnArgColAllOf
 from alchemite_apiclient.model.new_col_fn_arg_col_weights import NewColFnArgColWeights
@@ -148,6 +158,7 @@ from alchemite_apiclient.model.new_columns import NewColumns
 from alchemite_apiclient.model.non_empty_categorical_column import NonEmptyCategoricalColumn
 from alchemite_apiclient.model.non_empty_continuous_column import NonEmptyContinuousColumn
 from alchemite_apiclient.model.non_empty_integer_categorical_column import NonEmptyIntegerCategoricalColumn
+from alchemite_apiclient.model.numerical_filter import NumericalFilter
 from alchemite_apiclient.model.ot_sample_def_categorical import OTSampleDefCategorical
 from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContinuous
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
@@ -160,6 +171,7 @@ from alchemite_apiclient.model.output_tolerance_response_fixed_inputs import Out
 from alchemite_apiclient.model.output_tolerance_response_predicted_outputs import OutputToleranceResponsePredictedOutputs
 from alchemite_apiclient.model.output_tolerance_response_predictions import OutputToleranceResponsePredictions
 from alchemite_apiclient.model.output_tolerance_response_sampled_inputs import OutputToleranceResponseSampledInputs
+from alchemite_apiclient.model.output_tolerance_univariate_response import OutputToleranceUnivariateResponse
 from alchemite_apiclient.model.part_dependent_columns import PartDependentColumns
 from alchemite_apiclient.model.part_get_optimize import PartGetOptimize
 from alchemite_apiclient.model.part_get_optimize_done_result_array import PartGetOptimizeDoneResultArray
@@ -178,9 +190,8 @@ from alchemite_apiclient.model.predict_request import PredictRequest
 from alchemite_apiclient.model.prediction import Prediction
 from alchemite_apiclient.model.query_request import QueryRequest
 from alchemite_apiclient.model.query_response import QueryResponse
+from alchemite_apiclient.model.range import Range
 from alchemite_apiclient.model.si_sample_def_categorical import SISampleDefCategorical
-from alchemite_apiclient.model.si_sample_def_categorical_column_values import SISampleDefCategoricalColumnValues
-from alchemite_apiclient.model.si_sample_def_continuous import SISampleDefContinuous
 from alchemite_apiclient.model.si_sample_definition import SISampleDefinition
 from alchemite_apiclient.model.sample_def_categorical import SampleDefCategorical
 from alchemite_apiclient.model.sample_def_categorical_column_values import SampleDefCategoricalColumnValues
@@ -248,6 +259,7 @@ from alchemite_apiclient.model.tar_fn_weighted_sum_between_all_of import TarFnWe
 from alchemite_apiclient.model.target_function import TargetFunction
 from alchemite_apiclient.model.train_request import TrainRequest
 from alchemite_apiclient.model.training_dataset_outliers_request import TrainingDatasetOutliersRequest
+from alchemite_apiclient.model.training_validation_prediction_request import TrainingValidationPredictionRequest
 from alchemite_apiclient.model.validate_request import ValidateRequest
 from alchemite_apiclient.model.validation_split import ValidationSplit
 from alchemite_apiclient.model.value import Value
