@@ -28,8 +28,10 @@ model_name = "steels"
 
 # Check we can access the API by getting the version number from GET /version
 api_response = api_default.version_get()
-print("------ API version -----")
+print("------ API & Python Client Versions ------")
 print(api_response)
+print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print("------------------------------------------")
 
 ############################################################################
 ### Upload a dataset with POST /datasets
@@ -91,7 +93,7 @@ importance_request = {
     "useOnlyDescriptors": True
 }
 r = api_models.models_id_importance_put(
-    model_id, importance_request=importance_request, _preload_content=False
+    model_id, importance_request=importance_request
 )
-with open(importance_output_file, "wb") as f:
-    f.write(r.data)
+with open(importance_output_file, "w", encoding="UTF-8") as f:
+    f.write(r)
