@@ -17,9 +17,7 @@ def load_file_as_module(name, location):
 
 
 def pytest_configure(config):
-    config.addinivalue_line(
-        "markers", "invalid_request: test is expected to error"
-    )
+    config.addinivalue_line("markers", "invalid_request: test is expected to error")
 
 
 @pytest.mark.parametrize(
@@ -59,6 +57,11 @@ def pytest_configure(config):
             ["steels.csv"],
             id="importance",
         ),
+        pytest.param(
+            "metadata",
+            ["steels.csv"],
+            id="metadata",
+        ),
         pytest.param(
             "optimize",
             ["steels.csv", "optimize_args_steel.json"],
@@ -70,9 +73,7 @@ def pytest_configure(config):
             id="outliers",
         ),
         pytest.param("output_tolerance", ["steels.csv"], id="output_tolerance"),
-        pytest.param(
-            "preload", ["adrenergic.csv", "adrenergic_row.csv"], id="preload"
-        ),
+        pytest.param("preload", ["adrenergic.csv", "adrenergic_row.csv"], id="preload"),
         pytest.param("query", ["adrenergic.csv"], id="query"),
         pytest.param(
             "sensitivity",
@@ -114,11 +115,13 @@ def pytest_configure(config):
             ["vector.csv"],
             id="vector",
         ),
+        pytest.param("validation_request", ["steels.csv"], id="validation_request"),
     ],
 )
 def test_example(
     example_name,
     example_data,
+    example_dir,
     set_work_dir,
     written_credentials,
     set_insecure_transport,
@@ -127,8 +130,6 @@ def test_example(
     example_data.append(example_file_name)
 
     # Copy example_X.py and required data to test working directory
-    dir_path = os.path.dirname(os.path.realpath(__file__))
-    example_dir = os.path.join(dir_path, "..", "example")
     for file_name in example_data:
         shutil.copy(os.path.join(example_dir, file_name), set_work_dir)
 
